@@ -10,7 +10,7 @@ use Cwd;
 
 our @ISA = qw( Module::Build );
 
-our $wxpdfversion = '0.9.4';
+our $wxpdfversion = '0.9.5';
 
 our $VERSION = '0.62';
 
@@ -379,7 +379,7 @@ sub wxpdf_get_pdfdocument_source {
 			my $currentfilename;
 			
 			while(<$fh>) {
-				if( /^diff -ruNw -x\.svn -x docs [^\\\/]+[\\\/]([^\s]+).+$/ ) {
+				if( /^diff -ruN{0,1}w -x\.svn -x docs [^\\\/]+[\\\/]([^\s]+).+$/ ) {
 					push(@patches, [ $currentfilename, $currentpatch ] ) if $currentpatch;
 					$currentfilename = $1;
 					$currentpatch = '';
